==> liquidwar6-0.0.7beta.tar.gz: liquidwar6-0.0.7beta/src/lib/gfx/mod-gl/gl-view/gl-flat/gl-flat-internal.h <==
/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.


  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#ifndef LIQUIDWAR6GFX_MOD_GL_VIEW_FLAT_INTERNAL_H
#define LIQUIDWAR6GFX_MOD_GL_VIEW_FLAT_INTERNAL_H

#include "gl-flat.h"

typedef struct _mod_gl_view_flat_game_context_map_s
{
  int level_id;
  lw6map_level_t *level;
  mod_gl_utils_texture_array_t map_texture_array;
}
_mod_gl_view_flat_game_context_map_t;

typedef struct _mod_gl_view_flat_game_context_armies_s
{
  int game_struct_id;
  lw6ker_game_state_t *game_state;
  mod_gl_utils_surface_array_t armies_surface_array;
  mod_gl_utils_texture_array_t armies_texture_array;
}
_mod_gl_view_flat_game_context_armies_t;

typedef struct _mod_gl_view_flat_game_context_s
{
  _mod_gl_view_flat_game_context_map_t map;
  _mod_gl_view_flat_game_context_armies_t armies;
}
_mod_gl_view_flat_game_context_t;

typedef struct _mod_gl_view_flat_cursor_context_s
{
  u_int16_t cursor_id;
  char letter;
  int team_color;
  GLuint texture_even;
  GLuint texture_odd;
}
_mod_gl_view_flat_cursor_context_t;

typedef struct _mod_gl_view_flat_cursors_context_s
{
  lw6map_color_couple_t color;
  _mod_gl_view_flat_cursor_context_t cursor[LW6MAP_MAX_NB_CURSORS];
}
_mod_gl_view_flat_cursors_context_t;

typedef struct _mod_gl_view_flat_const_data_s
{
  float cursor_size_min;
  float cursor_size_max;
  float scroll_limit;
  int scroll_min_offset;
  int cursor_blink_period;
  int cursor_heartbeat_period;
  int cursor_texture_size;
  int cursor_border_width;
  int cursor_blur_width;
  int tile_size_map;
  int tile_size_armies;
}
_mod_gl_view_flat_const_data_t;

/*
typedef struct _mod_gl_view_flat_smoothers_s
{
  //float last_zoom;
  //int last_center_x;
  //int last_center_y;
  lw6gui_smoother_t center_x;
  lw6gui_smoother_t center_y;
}
_mod_gl_view_flat_smoothers_t;
*/

typedef struct _mod_gl_view_flat_context_s
{
  _mod_gl_view_flat_game_context_t game_context;
  _mod_gl_view_flat_cursors_context_t cursors_context;
  _mod_gl_view_flat_const_data_t const_data;
  //_mod_gl_view_flat_smoother_t smoothers;
  lw6gui_viewport_t viewport;
}
_mod_gl_view_flat_context_t;

/*
 * In cursorcontext.c
 */
extern int _mod_gl_view_flat_cursor_context_init (mod_gl_utils_context_t *
						  utils_context,
						  _mod_gl_view_flat_cursor_context_t
						  * cursor_context,
						  _mod_gl_view_flat_const_data_t
						  * const_data,
						  lw6gui_look_t * look,
						  lw6ker_cursor_t * cursor);
extern int _mod_gl_view_flat_cursor_context_update (mod_gl_utils_context_t *
						    utils_context,
						    _mod_gl_view_flat_cursor_context_t
						    * cursor_context,
						    _mod_gl_view_flat_const_data_t
						    * const_data,
						    lw6gui_look_t * look,
						    lw6ker_cursor_t * cursor);
extern int _mod_gl_view_flat_cursor_context_clear (mod_gl_utils_context_t *
						   utils_context,
						   _mod_gl_view_flat_cursor_context_t
						   * cursor_context);
extern int _mod_gl_view_flat_cursors_context_init (mod_gl_utils_context_t *
						   utils_context,
						   _mod_gl_view_flat_cursors_context_t
						   * cursors_context,
						   _mod_gl_view_flat_const_data_t
						   * const_data,
						   lw6gui_look_t * look,
						   lw6ker_game_state_t *
						   game_state);
extern int _mod_gl_view_flat_cursors_context_update (mod_gl_utils_context_t *
						     utils_context,
						     _mod_gl_view_flat_cursors_context_t
						     * cursors_context,
						     _mod_gl_view_flat_const_data_t
						     * const_data,
						     lw6gui_look_t * look,
						     lw6ker_game_state_t *
						     game_state);
extern int _mod_gl_view_flat_cursors_context_clear (mod_gl_utils_context_t *
						    utils_context,
						    _mod_gl_view_flat_cursors_context_t
						    * cursors_context);

/*
 * In data.c
 */
extern int _mod_gl_view_flat_load_data (mod_gl_utils_context_t *
					utils_context,
					_mod_gl_view_flat_context_t *
					flat_context);
extern void _mod_gl_view_flat_unload_data (mod_gl_utils_context_t *
					   utils_context,
					   _mod_gl_view_flat_context_t *
					   flat_context);

/*
 * In display.c
 */
extern void _mod_gl_view_flat_display_preview (mod_gl_utils_context_t *
					       utils_context,
					       _mod_gl_view_flat_context_t *
					       flat_context,
					       lw6gui_look_t * look,
					       lw6map_level_t * level);
extern void _mod_gl_view_flat_display_map (mod_gl_utils_context_t *
					   utils_context,
					   _mod_gl_view_flat_context_t *
					   flat_context,
					   lw6gui_look_t * look,
					   lw6ker_game_state_t * game_state,
					   lw6gui_main_cursor_t *
					   main_cursor);
extern void _mod_gl_view_flat_display_fighters (mod_gl_utils_context_t *
						utils_context,
						_mod_gl_view_flat_context_t *
						flat_context,
						lw6gui_look_t * look,
						lw6ker_game_state_t *
						game_state,
						lw6gui_main_cursor_t *
						main_cursor);
extern void _mod_gl_view_flat_display_cursors (mod_gl_utils_context_t *
					       utils_context,
					       _mod_gl_view_flat_context_t *
					       flat_context,
					       lw6gui_look_t * look,
					       lw6ker_game_state_t *
					       game_state,
					       lw6gui_main_cursor_t *
					       main_cursor);

/*
 * In gamecontext.c
 */
extern int _mod_gl_view_flat_game_context_init (mod_gl_utils_context_t *
						utils_context,
						_mod_gl_view_flat_context_t
						* flat_context,
						_mod_gl_view_flat_game_context_t
						* game_context,
						lw6gui_look_t * look,
						lw6map_level_t * level,
						lw6ker_game_state_t *
						game_state);
extern int _mod_gl_view_flat_game_context_init_map (mod_gl_utils_context_t *
						    utils_context,
						    _mod_gl_view_flat_context_t
						    * flat_context,
						    _mod_gl_view_flat_game_context_map_t
						    * game_context_map,
						    lw6gui_look_t * look,
						    lw6map_level_t * level);
extern int _mod_gl_view_flat_game_context_init_armies (mod_gl_utils_context_t
						       * utils_context,
						       _mod_gl_view_flat_context_t
						       * flat_context,
						       _mod_gl_view_flat_game_context_armies_t
						       * game_context_armies,
						       lw6gui_look_t * look,
						       lw6ker_game_state_t *
						       game_state);
extern void _mod_gl_view_flat_game_context_clear (mod_gl_utils_context_t *
						  utils_context,
						  _mod_gl_view_flat_context_t
						  * flat_context,
						  _mod_gl_view_flat_game_context_t
						  * game_context);
extern void _mod_gl_view_flat_game_context_clear_map (mod_gl_utils_context_t *
						      utils_context,
						      _mod_gl_view_flat_context_t
						      * flat_context,
						      _mod_gl_view_flat_game_context_map_t
						      * game_context_map);
extern void
_mod_gl_view_flat_game_context_clear_armies (mod_gl_utils_context_t *
					     utils_context,
					     _mod_gl_view_flat_context_t *
					     flat_context,
					     _mod_gl_view_flat_game_context_armies_t
					     * game_context_armies);
extern int _mod_gl_view_flat_game_context_update (mod_gl_utils_context_t *
						  utils_context,
						  _mod_gl_view_flat_context_t
						  * flat_context,
						  _mod_gl_view_flat_game_context_t
						  * game_context,
						  lw6gui_look_t * look,
						  lw6map_level_t * level,
						  lw6ker_game_state_t *
						  game_state);
extern int _mod_gl_view_flat_game_context_update_map (mod_gl_utils_context_t *
						      utils_context,
						      _mod_gl_view_flat_context_t
						      * flat_context,
						      _mod_gl_view_flat_game_context_map_t
						      * game_context_map,
						      lw6gui_look_t * look,
						      lw6map_level_t * level);
extern int
_mod_gl_view_flat_game_context_update_armies (mod_gl_utils_context_t *
					      utils_context,
					      _mod_gl_view_flat_context_t *
					      flat_context,
					      _mod_gl_view_flat_game_context_armies_t
					      * game_context_armies,
					      lw6gui_look_t * look,
					      lw6ker_game_state_t *
					      game_state);

/*
 * In setup.c
 */
extern _mod_gl_view_flat_context_t
  * _mod_gl_view_flat_init (mod_gl_utils_context_t * utils_context);
extern void _mod_gl_view_flat_quit (mod_gl_utils_context_t * utils_context,
				    _mod_gl_view_flat_context_t *
				    flat_context);

/*
 * in viewport.c
 */
extern void _mod_gl_view_flat_viewport_update_preview (mod_gl_utils_context_t
						       * utils_context,
						       _mod_gl_view_flat_context_t
						       * flat_context,
						       lw6gui_look_t * look,
						       lw6map_level_t *
						       level);
extern void _mod_gl_view_flat_viewport_update (mod_gl_utils_context_t *
					       utils_context,
					       _mod_gl_view_flat_context_t *
					       flat_context,
					       lw6gui_look_t * look,
					       lw6ker_game_state_t *
					       game_state,
					       lw6gui_main_cursor_t *
					       main_cursor);

#endif

==> liquidwar6-0.0.8beta.tar.gz: liquidwar6-0.0.8beta/src/lib/gfx/mod-gl/gl-view/gl-flat/gl-flat-internal.h <==
/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.


  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#ifndef LIQUIDWAR6GFX_MOD_GL_VIEW_FLAT_INTERNAL_H
#define LIQUIDWAR6GFX_MOD_GL_VIEW_FLAT_INTERNAL_H

#include "gl-flat.h"

typedef struct _mod_gl_view_flat_game_context_map_s
{
  int level_id;
  lw6map_level_t *level;
  mod_gl_utils_bitmap_array_t map_bitmap_array;
}
_mod_gl_view_flat_game_context_map_t;

typedef struct _mod_gl_view_flat_game_context_armies_s
{
  int game_struct_id;
  lw6ker_game_state_t *game_state;
  mod_gl_utils_bitmap_array_t armies_bitmap_array;
}
_mod_gl_view_flat_game_context_armies_t;

typedef struct _mod_gl_view_flat_game_context_s
{
  _mod_gl_view_flat_game_context_map_t map;
  _mod_gl_view_flat_game_context_armies_t armies;
}
_mod_gl_view_flat_game_context_t;

typedef struct _mod_gl_view_flat_cursor_context_s
{
  u_int16_t cursor_id;
  char letter;
  int team_color;
  mod_gl_utils_bitmap_t *bitmap_even;
  mod_gl_utils_bitmap_t *bitmap_odd;
}
_mod_gl_view_flat_cursor_context_t;

typedef struct _mod_gl_view_flat_cursors_context_s
{
  lw6map_color_couple_t color;
  _mod_gl_view_flat_cursor_context_t cursor[LW6MAP_MAX_NB_CURSORS];
}
_mod_gl_view_flat_cursors_context_t;

typedef struct _mod_gl_view_flat_const_data_s
{
  float cursor_size_min;
  float cursor_size_max;
  float scroll_limit;
  int scroll_min_offset;
  int cursor_blink_period;
  int cursor_heartbeat_period;
  int cursor_texture_size;
  int cursor_border_width;
  int cursor_blur_width;
  int tile_size_map;
  int tile_size_armies;
}
_mod_gl_view_flat_const_data_t;

/*
typedef struct _mod_gl_view_flat_smoothers_s
{
  //float last_zoom;
  //int last_center_x;
  //int last_center_y;
  lw6gui_smoother_t center_x;
  lw6gui_smoother_t center_y;
}
_mod_gl_view_flat_smoothers_t;
*/

typedef struct _mod_gl_view_flat_context_s
{
  _mod_gl_view_flat_game_context_t game_context;
  _mod_gl_view_flat_cursors_context_t cursors_context;
  _mod_gl_view_flat_const_data_t const_data;
  //_mod_gl_view_flat_smoother_t smoothers;
  lw6gui_viewport_t viewport;
}
_mod_gl_view_flat_context_t;

/*
 * In cursorcontext.c
 */
extern int _mod_gl_view_flat_cursor_context_init (mod_gl_utils_context_t *
						  utils_context,
						  _mod_gl_view_flat_cursor_context_t
						  * cursor_context,
						  _mod_gl_view_flat_const_data_t
						  * const_data,
						  lw6gui_look_t * look,
						  lw6ker_cursor_t * cursor);
extern int _mod_gl_view_flat_cursor_context_update (mod_gl_utils_context_t *
						    utils_context,
						    _mod_gl_view_flat_cursor_context_t
						    * cursor_context,
						    _mod_gl_view_flat_const_data_t
						    * const_data,
						    lw6gui_look_t * look,
						    lw6ker_cursor_t * cursor);
extern int _mod_gl_view_flat_cursor_context_clear (mod_gl_utils_context_t *
						   utils_context,
						   _mod_gl_view_flat_cursor_context_t
						   * cursor_context);
extern int _mod_gl_view_flat_cursors_context_init (mod_gl_utils_context_t *
						   utils_context,
						   _mod_gl_view_flat_cursors_context_t
						   * cursors_context,
						   _mod_gl_view_flat_const_data_t
						   * const_data,
						   lw6gui_look_t * look,
						   lw6ker_game_state_t *
						   game_state);
extern int _mod_gl_view_flat_cursors_context_update (mod_gl_utils_context_t *
						     utils_context,
						     _mod_gl_view_flat_cursors_context_t
						     * cursors_context,
						     _mod_gl_view_flat_const_data_t
						     * const_data,
						     lw6gui_look_t * look,
						     lw6ker_game_state_t *
						     game_state);
extern int _mod_gl_view_flat_cursors_context_clear (mod_gl_utils_context_t *
						    utils_context,
						    _mod_gl_view_flat_cursors_context_t
						    * cursors_context);

/*
 * In data.c
 */
extern int _mod_gl_view_flat_load_data (mod_gl_utils_context_t *
					utils_context,
					_mod_gl_view_flat_context_t *
					flat_context);
extern void _mod_gl_view_flat_unload_data (mod_gl_utils_context_t *
					   utils_context,
					   _mod_gl_view_flat_context_t *
					   flat_context);

/*
 * In display.c
 */
extern void _mod_gl_view_flat_display_preview (mod_gl_utils_context_t *
					       utils_context,
					       _mod_gl_view_flat_context_t *
					       flat_context,
					       lw6gui_look_t * look,
					       lw6map_level_t * level);
extern void _mod_gl_view_flat_display_map (mod_gl_utils_context_t *
					   utils_context,
					   _mod_gl_view_flat_context_t *
					   flat_context,
					   lw6gui_look_t * look,
					   lw6ker_game_state_t * game_state,
					   lw6pil_local_cursors_t *
					   local_cursors);
extern void _mod_gl_view_flat_display_fighters (mod_gl_utils_context_t *
						utils_context,
						_mod_gl_view_flat_context_t *
						flat_context,
						lw6gui_look_t * look,
						lw6ker_game_state_t *
						game_state,
						lw6pil_local_cursors_t *
						local_cursors);
extern void _mod_gl_view_flat_display_cursors (mod_gl_utils_context_t *
					       utils_context,
					       _mod_gl_view_flat_context_t *
					       flat_context,
					       lw6gui_look_t * look,
					       lw6ker_game_state_t *
					       game_state,
					       lw6pil_local_cursors_t *
					       local_cursors);

/*
 * In gamecontext.c
 */
extern int _mod_gl_view_flat_game_context_init (mod_gl_utils_context_t *
						utils_context,
						_mod_gl_view_flat_context_t
						* flat_context,
						_mod_gl_view_flat_game_context_t
						* game_context,
						lw6gui_look_t * look,
						lw6map_level_t * level,
						lw6ker_game_state_t *
						game_state);
extern int _mod_gl_view_flat_game_context_init_map (mod_gl_utils_context_t *
						    utils_context,
						    _mod_gl_view_flat_context_t
						    * flat_context,
						    _mod_gl_view_flat_game_context_map_t
						    * game_context_map,
						    lw6gui_look_t * look,
						    lw6map_level_t * level);
extern int _mod_gl_view_flat_game_context_init_armies (mod_gl_utils_context_t
						       * utils_context,
						       _mod_gl_view_flat_context_t
						       * flat_context,
						       _mod_gl_view_flat_game_context_armies_t
						       * game_context_armies,
						       lw6gui_look_t * look,
						       lw6ker_game_state_t *
						       game_state);
extern void _mod_gl_view_flat_game_context_clear (mod_gl_utils_context_t *
						  utils_context,
						  _mod_gl_view_flat_context_t
						  * flat_context,
						  _mod_gl_view_flat_game_context_t
						  * game_context);
extern void _mod_gl_view_flat_game_context_clear_map (mod_gl_utils_context_t *
						      utils_context,
						      _mod_gl_view_flat_context_t
						      * flat_context,
						      _mod_gl_view_flat_game_context_map_t
						      * game_context_map);
extern void
_mod_gl_view_flat_game_context_clear_armies (mod_gl_utils_context_t *
					     utils_context,
					     _mod_gl_view_flat_context_t *
					     flat_context,
					     _mod_gl_view_flat_game_context_armies_t
					     * game_context_armies);
extern int _mod_gl_view_flat_game_context_update (mod_gl_utils_context_t *
						  utils_context,
						  _mod_gl_view_flat_context_t
						  * flat_context,
						  _mod_gl_view_flat_game_context_t
						  * game_context,
						  lw6gui_look_t * look,
						  lw6map_level_t * level,
						  lw6ker_game_state_t *
						  game_state);
extern int _mod_gl_view_flat_game_context_update_map (mod_gl_utils_context_t *
						      utils_context,
						      _mod_gl_view_flat_context_t
						      * flat_context,
						      _mod_gl_view_flat_game_context_map_t
						      * game_context_map,
						      lw6gui_look_t * look,
						      lw6map_level_t * level);
extern int
_mod_gl_view_flat_game_context_update_armies (mod_gl_utils_context_t *
					      utils_context,
					      _mod_gl_view_flat_context_t *
					      flat_context,
					      _mod_gl_view_flat_game_context_armies_t
					      * game_context_armies,
					      lw6gui_look_t * look,
					      lw6ker_game_state_t *
					      game_state);

/*
 * In setup.c
 */
extern _mod_gl_view_flat_context_t
  * _mod_gl_view_flat_init (mod_gl_utils_context_t * utils_context);
extern void _mod_gl_view_flat_quit (mod_gl_utils_context_t * utils_context,
				    _mod_gl_view_flat_context_t *
				    flat_context);

/*
 * in viewport.c
 */
extern void _mod_gl_view_flat_viewport_update_preview (mod_gl_utils_context_t
						       * utils_context,
						       _mod_gl_view_flat_context_t
						       * flat_context,
						       lw6gui_look_t * look,
						       lw6map_level_t *
						       level);
extern void _mod_gl_view_flat_viewport_update (mod_gl_utils_context_t *
					       utils_context,
					       _mod_gl_view_flat_context_t *
					       flat_context,
					       lw6gui_look_t * look,
					       lw6ker_game_state_t *
					       game_state,
					       lw6pil_local_cursors_t *
					       local_cursors);

#endif
